@@ -4,9 +4,9 @@
 
 ;; Author: Noboru Ota <me@nobiot.com>
 ;; URL: https://github.com/nobiot/org-remark
-;; Version: 1.0.2
+;; Version: 1.0.3
 ;; Created: 22 December 2020
-;; Last modified: 14 February 2022
+;; Last modified: 28 February 2022
 ;; Package-Requires: ((emacs "27.1") (org "9.4"))
 ;; Keywords: org-mode, annotation, writing, note-taking, marginal-notes
 
@@ -957,6 +957,7 @@ Each highlight is a list in the following structure:
              ;; Narrow to only subtree for a single file.  `org-find-property'
              ;; ensures that it is the beginning of a headline
              (org-narrow-to-subtree)
+             (org-show-children)
              ;; It's important that the headline levels are fixed
              ;; H1: File
              ;; H2: Highlighted region (each one has a dedicated H2 subtree)
@@ -1078,10 +1079,13 @@ Returns the standardized filename.
 
 The current buffer is assumed to be visiting the source file.
 
-FILENAME should be an absolute file name of the source file."
+FILENAME should be an absolute file name of the source file.
+
+If FILENAME is nil, return nil."
   ;; Get the default-directory of the notes
-  (with-current-buffer (find-file-noselect (org-remark-notes-get-file-name))
-    (funcall org-remark-source-file-name filename)))
+  (when filename ; fix #23
+    (with-current-buffer (find-file-noselect (org-remark-notes-get-file-name))
+      (funcall org-remark-source-file-name filename))))
 
 (defun org-remark-region-or-word ()
   "Return beg and end of the active region or of the word at point.
